HostAccessible

Trait HostAccessible 

pub unsafe trait HostAccessible { }
A marker trait for host-accessible USM allocators.

Safety

A type implementing this trait must be a valid USM allocator managed by a SYCL runtime, that allocates memory accessible from the host.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors