pub unsafe trait UsmAlloc: Allocator { }Expand description
A marker trait for USM allocators.
Safety: a type implementing this trait must be a valid USM allocator managed by a SYCL runtime.
pub unsafe trait UsmAlloc: Allocator { }A marker trait for USM allocators.
Safety: a type implementing this trait must be a valid USM allocator managed by a SYCL runtime.