HostAccessible

Trait HostAccessible 

pub unsafe trait HostAccessible { }
A marker trait for host-accessible USM allocators.

Safety: a type implementing this trait must be a valid USM allocator managed by a SYCL runtime, that allocates memory accessible from the host.

Implementors